@@ -1,5 +1,7 @@
 import os
 from .createreact import create 
+from .visuals import complete_msg
+
 def manipulate_settings(setting_file, app_name):
     with open(setting_file, 'r') as b:
         lines = b.readlines()
@@ -105,3 +107,4 @@ def startDjangoProject(name, app_name = "reactfrontend"):
     manipulate_app_view('views.py', app_name)
     manipulate_app_urls('urls.py', app_name)
     create()
+    complete_msg(name)
